================
Auxiliary Module
================

Helper Functions used in the WaterML module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pywaterml.auxiliaryMod
   :members:
   :private-members:
